@@ -44,7 +44,7 @@ See the README file for an example usage of this module.
 """
 
 
-__version__ = "$Id: cloghandler.py 6037 2009-05-26 17:46:53Z lowell $"
+__version__ = "$Id: cloghandler.py 6175 2009-11-02 18:40:35Z lowell $"
 __author__ = "Lowell Alleman"
 __all__ = [
     "ConcurrentRotatingFileHandler",
@@ -161,7 +161,12 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
         self._rotateFailed = False
         self.maxBytes = maxBytes
         self.backupCount = backupCount
-        self.stream_lock = open(filename.replace(".log","") + ".lock", "w")
+        # Prevent multiple extensions on the lock file (Only handles the normal "*.log" case.)
+        if filename.endswith(".log"):
+            lock_file = filename[:-4]
+        else:
+            lock_file = filename
+        self.stream_lock = open(lock_file + ".lock", "w")
         
         # For debug mode, swap out the "_degrade()" method with a more a verbose one.
         if debug:
